@@ -14,7 +14,7 @@ use crate::config;
 use crate::gitlab::Labels as GLLabels;
 use crate::gitlab::ProjectMembers as GLMembers;
 use crate::gitlab::Project as GLProject;
-use crate::gitlab::Query;
+use crate::gitlab::{api, Query};
 use crate::gitlab;
 use crate::utils;
 
@@ -126,7 +126,7 @@ fn get_proj_id_by_remote(url: &str, gitlabclient: &gitlab::Client) -> Result<u64
 }
 
 fn get_project_members(project_id: u64, gitlabclient: &gitlab::Client) -> Result<Vec<String>> {
-    let mut members_builder = GLMembers::builder();
+    let mut members_builder = GLMembers::all_builder();
     let endpoint = members_builder.project(project_id).build()
         .map_err(|e| anyhow!("Could not fetch project members from server.\n {}",e))?;
 
@@ -198,7 +198,7 @@ fn get_project_labels(project_id: u64, gitlabclient: &gitlab::Client) -> Result<
         name: String
     }
 
-    let labels: Vec<Label> = endpoint
+    let labels: Vec<Label> = api::paged(endpoint, api::Pagination::Limit(80))
         .query(gitlabclient)
         .context("Failed to query project labels")?;
 
